@@ -17,7 +17,7 @@ from collections import OrderedDict
 from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
@@ -330,15 +330,12 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
                 client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
-                always_use_jwt_access=(
-                    Transport == type(self).get_transport_class("grpc")
-                    or Transport == type(self).get_transport_class("grpc_asyncio")
-                ),
+                always_use_jwt_access=True,
             )
 
     def compute_threat_list_diff(
         self,
-        request: webrisk.ComputeThreatListDiffRequest = None,
+        request: Union[webrisk.ComputeThreatListDiffRequest, dict] = None,
         *,
         threat_type: webrisk.ThreatType = None,
         version_token: bytes = None,
@@ -357,7 +354,7 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         once for each list.
 
         Args:
-            request (google.cloud.webrisk_v1.types.ComputeThreatListDiffRequest):
+            request (Union[google.cloud.webrisk_v1.types.ComputeThreatListDiffRequest, dict]):
                 The request object. Describes an API diff request.
             threat_type (google.cloud.webrisk_v1.types.ThreatType):
                 Required. The threat list to update.
@@ -435,7 +432,7 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
 
     def search_uris(
         self,
-        request: webrisk.SearchUrisRequest = None,
+        request: Union[webrisk.SearchUrisRequest, dict] = None,
         *,
         uri: str = None,
         threat_types: Sequence[webrisk.ThreatType] = None,
@@ -451,7 +448,7 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         response will be returned.
 
         Args:
-            request (google.cloud.webrisk_v1.types.SearchUrisRequest):
+            request (Union[google.cloud.webrisk_v1.types.SearchUrisRequest, dict]):
                 The request object. Request to check URI entries against
                 threatLists.
             uri (str):
@@ -514,7 +511,7 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
 
     def search_hashes(
         self,
-        request: webrisk.SearchHashesRequest = None,
+        request: Union[webrisk.SearchHashesRequest, dict] = None,
         *,
         hash_prefix: bytes = None,
         threat_types: Sequence[webrisk.ThreatType] = None,
@@ -530,7 +527,7 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         match of a threat.
 
         Args:
-            request (google.cloud.webrisk_v1.types.SearchHashesRequest):
+            request (Union[google.cloud.webrisk_v1.types.SearchHashesRequest, dict]):
                 The request object. Request to return full hashes
                 matched by the provided hash prefixes.
             hash_prefix (bytes):
@@ -595,7 +592,7 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
 
     def create_submission(
         self,
-        request: webrisk.CreateSubmissionRequest = None,
+        request: Union[webrisk.CreateSubmissionRequest, dict] = None,
         *,
         parent: str = None,
         submission: webrisk.Submission = None,
@@ -613,7 +610,7 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         visibility can use this method.
 
         Args:
-            request (google.cloud.webrisk_v1.types.CreateSubmissionRequest):
+            request (Union[google.cloud.webrisk_v1.types.CreateSubmissionRequest, dict]):
                 The request object. Request to send a potentially phishy
                 URI to WebRisk.
             parent (str):
@@ -683,6 +680,19 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         # Done; return the response.
         return response
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, type, value, traceback):
+        """Releases underlying transport's resources.
+
+        .. warning::
+            ONLY use as a context manager if the transport is NOT shared
+            with other clients! Exiting the with block will CLOSE the transport
+            and may cause errors in other clients!
+        """
+        self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
