@@ -17,7 +17,7 @@ from collections import OrderedDict
 from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
@@ -332,15 +332,12 @@ class WebRiskServiceV1Beta1Client(metaclass=WebRiskServiceV1Beta1ClientMeta):
                 client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
-                always_use_jwt_access=(
-                    Transport == type(self).get_transport_class("grpc")
-                    or Transport == type(self).get_transport_class("grpc_asyncio")
-                ),
+                always_use_jwt_access=True,
             )
 
     def compute_threat_list_diff(
         self,
-        request: webrisk.ComputeThreatListDiffRequest = None,
+        request: Union[webrisk.ComputeThreatListDiffRequest, dict] = None,
         *,
         threat_type: webrisk.ThreatType = None,
         version_token: bytes = None,
@@ -352,7 +349,7 @@ class WebRiskServiceV1Beta1Client(metaclass=WebRiskServiceV1Beta1ClientMeta):
         r"""Gets the most recent threat list diffs.
 
         Args:
-            request (google.cloud.webrisk_v1beta1.types.ComputeThreatListDiffRequest):
+            request (Union[google.cloud.webrisk_v1beta1.types.ComputeThreatListDiffRequest, dict]):
                 The request object. Describes an API diff request.
             threat_type (google.cloud.webrisk_v1beta1.types.ThreatType):
                 The ThreatList to update.
@@ -422,7 +419,7 @@ class WebRiskServiceV1Beta1Client(metaclass=WebRiskServiceV1Beta1ClientMeta):
 
     def search_uris(
         self,
-        request: webrisk.SearchUrisRequest = None,
+        request: Union[webrisk.SearchUrisRequest, dict] = None,
         *,
         uri: str = None,
         threat_types: Sequence[webrisk.ThreatType] = None,
@@ -434,7 +431,7 @@ class WebRiskServiceV1Beta1Client(metaclass=WebRiskServiceV1Beta1ClientMeta):
         given threatList.
 
         Args:
-            request (google.cloud.webrisk_v1beta1.types.SearchUrisRequest):
+            request (Union[google.cloud.webrisk_v1beta1.types.SearchUrisRequest, dict]):
                 The request object. Request to check URI entries against
                 threatLists.
             uri (str):
@@ -496,7 +493,7 @@ class WebRiskServiceV1Beta1Client(metaclass=WebRiskServiceV1Beta1ClientMeta):
 
     def search_hashes(
         self,
-        request: webrisk.SearchHashesRequest = None,
+        request: Union[webrisk.SearchHashesRequest, dict] = None,
         *,
         hash_prefix: bytes = None,
         threat_types: Sequence[webrisk.ThreatType] = None,
@@ -512,7 +509,7 @@ class WebRiskServiceV1Beta1Client(metaclass=WebRiskServiceV1Beta1ClientMeta):
         match of a threat.
 
         Args:
-            request (google.cloud.webrisk_v1beta1.types.SearchHashesRequest):
+            request (Union[google.cloud.webrisk_v1beta1.types.SearchHashesRequest, dict]):
                 The request object. Request to return full hashes
                 matched by the provided hash prefixes.
             hash_prefix (bytes):
@@ -574,6 +571,19 @@ class WebRiskServiceV1Beta1Client(metaclass=WebRiskServiceV1Beta1ClientMeta):
         # Done; return the response.
         return response
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, type, value, traceback):
+        """Releases underlying transport's resources.
+
+        .. warning::
+            ONLY use as a context manager if the transport is NOT shared
+            with other clients! Exiting the with block will CLOSE the transport
+            and may cause errors in other clients!
+        """
+        self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
